#!/usr/bin/env python

"""
Java Servlet adapter.
"""

from WebStack import JavaServlet

class Dispatcher:

    "A servlet helper class dispatching requests to WebStack resources."

    def __init__(self, resource, authenticator=None):

        """
        Initialise the root application-specific 'resource' and optional
        'authenticator'.
        """

        self.webstack_resource = resource
        self.webstack_authenticator = authenticator

    def service(self, request, response):

        """
        Handle the 'request' and 'response' presented by the servlet.
        """

        trans = WebStack.JavaServlet.Transaction(request, response)
        if self.webstack_authenticator is None or self.webstack_authenticator.authenticate(trans):
            self.webstack_resource.respond(trans)
        else:
            trans.set_response_code(401) # Unauthorized
            trans.set_header_value("WWW-Authenticate", '%s realm="%s"' % (
                self.webstack_authenticator.get_auth_type(), self.webstack_authenticator.get_realm()))

        trans.commit()

# vim: tabstop=4 expandtab shiftwidth=4
